@@ -1,6 +1,6 @@
 /* proxy_session.h
  *
- * $Id: proxy_session.h,v 1.1 1999/11/29 20:53:52 nisse Exp $ */
+ * $Id: proxy_session.h,v 1.2 2000/01/12 22:40:13 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -28,6 +28,7 @@
 #include "channel.h"
 
 struct channel_open *
-make_proxy_open_session(struct alist *session_requests);
+make_proxy_open_session(struct alist *server_requests,
+			struct alist *client_requests);
 
 #endif /* LSH_PROXY_SESSION_H_INCLUDED */
